From b95717b19a93ceb33dddf7d85aeb9809b5f34e03 Mon Sep 17 00:00:00 2001
From: derek riemer <derek.riemer@colorado.edu>
Date: Wed, 25 Feb 2015 15:39:05 -0800
Subject: [PATCH] fixed t4308, Nvda no longer ~should omit the first character 
 while speaking a removed selection change.

---
 source/controlTypes.py |  2 ++
 source/speech.py       | 14 ++++++++------
 2 files changed, 10 insertions(+), 6 deletions(-)

diff --git a/source/controlTypes.py b/source/controlTypes.py
index 445f292..2670abc 100644
--- a/source/controlTypes.py
+++ b/source/controlTypes.py
@@ -599,6 +599,8 @@ REASON_SAYALL="sayAll"
 REASON_CARET="caret"
 #: No output, but any state should be cached as if output had occurred.
 REASON_ONLYCACHE="onlyCache"
+#: Selection removed, but character was typed.
+REASON_SELECTION_REMOVED="selection removed"
 #}
 
 def processPositiveStates(role, states, reason, positiveStates):
diff --git a/source/speech.py b/source/speech.py
index 105b784..5ab5065 100755
--- a/source/speech.py
+++ b/source/speech.py
@@ -1,4 +1,4 @@
-# -*- coding: UTF-8 -*-
+﻿# -*- coding: UTF-8 -*-
 #speech.py
 #A part of NonVisual Desktop Access (NVDA)
 #This file is covered by the GNU General Public License.
@@ -39,7 +39,7 @@ curWordChars=[]
 
 # The REASON_* constants in this module are deprecated and will be removed in a future release.
 # Use controlTypes.REASON_* instead.
-from controlTypes import REASON_FOCUS, REASON_FOCUSENTERED, REASON_MOUSE, REASON_QUERY, REASON_CHANGE, REASON_MESSAGE, REASON_SAYALL, REASON_CARET, REASON_ONLYCACHE
+from controlTypes import REASON_FOCUS, REASON_FOCUSENTERED, REASON_MOUSE, REASON_QUERY, REASON_CHANGE, REASON_MESSAGE, REASON_SAYALL, REASON_CARET, REASON_ONLYCACHE, REASON_SELECTION_REMOVED
 
 #: The string used to separate distinct chunks of text when multiple chunks should be spoken without pauses.
 # #555: Use two spaces so that numbers from adjacent chunks aren't treated as a single number
@@ -349,7 +349,7 @@ def speakText(text,index=None,reason=controlTypes.REASON_MESSAGE,symbolLevel=Non
 			# Translators: This is spoken when the line is considered blank.
 			text=_("blank")
 		speechSequence.append(text)
-	speak(speechSequence,symbolLevel=symbolLevel)
+	speak(speechSequence,symbolLevel=symbolLevel, reason=reason)
 
 RE_INDENTATION_SPLIT = re.compile(r"^([^\S\r\n\f\v]*)(.*)$", re.UNICODE | re.DOTALL)
 def splitTextIndentation(text):
@@ -391,10 +391,11 @@ def getIndentationSpeech(indentation):
 
 	return " ".join(res)
 
-def speak(speechSequence,symbolLevel=None):
+def speak(speechSequence, symbolLevel=None, reason=None):
 	"""Speaks a sequence of text and speech commands
 	@param speechSequence: the sequence of text and L{SpeechCommand} objects to speak
 	@param symbolLevel: The symbol verbosity level; C{None} (default) to use the user's configuration.
+	@param reason: The reason for speaking this text; C{None} (default) to use the default.
 	"""
 	if not speechSequence: #Pointless - nothing to speak 
 		return
@@ -404,7 +405,8 @@ def speak(speechSequence,symbolLevel=None):
 			if isinstance(item,basestring):
 				speechViewer.appendText(item)
 	global beenCanceled, curWordChars
-	curWordChars=[]
+	if reason != REASON_SELECTION_REMOVED:
+		curWordChars=[]
 	if speechMode==speechMode_off:
 		return
 	elif speechMode==speechMode_beeps:
@@ -526,7 +528,7 @@ def speakSelectionChange(oldInfo,newInfo,speakSelected=True,speakUnselected=True
 				speakSelectionMessage(_("unselecting %s"),text)
 		elif len(unselectedTextList)>0:
 			# Translators: Reported when selection is removed.
-			speakMessage(_("selection removed"))
+			speakText(_("selection removed"), reason=REASON_SELECTION_REMOVED)
 			if not newInfo.isCollapsed:
 				text=newInfo.text
 				if len(text)==1:
-- 
1.9.4.msysgit.0

